<?php

/**
 * This file contains package_ecoyn_dashboard_ajax_backend_getCategory
 */

/**
 * @return array
 */

use QUI\ERP\Defaults;

QUI::$Ajax->registerFunction(
    'package_ecoyn_dashboard_ajax_backend_getCategory',
    function ($time) {
        $time = json_decode($time, true);
        $from = date('Y-m-d H:i:s', $time['from']);
        $to = date('Y-m-d H:i:s', $time['to']);

        $FromDate = new DateTime($from);
        $ToDate = new DateTime($to);

        $Interval = new DateInterval('P1D');
        $Period = new DatePeriod($FromDate, $Interval, $ToDate);
        $result = [];

        $Currency = Defaults::getCurrency();

        foreach ($Period as $Day) {
            $day = $Day->format('Y-m-d');
            $dayCache = Ecoyn\Dashboard\Cron::CACHE_ORDER_CATEGORIES . $day;

            try {
                $cache = QUI\Cache\LongTermCache::get($dayCache);
            } catch (QUI\Exception) {
                continue;
            }

            foreach ($cache as $catId => $data) {
                if (!isset($result[$catId])) {
                    $result[$catId] = [
                        'sum' => floatval($data['sum']),
                        'title' => QUI::getLocale()->get(
                            'quiqqer/products',
                            'products.category.' . $catId . '.title'
                        )
                    ];

                    continue;
                }

                $result[$catId]['sum'] = round(
                    $result[$catId]['sum'] + floatval($data['sum']),
                    $Currency->getPrecision()
                );
            }
        }

        return $result;
    },
    ['time'],
    'Permission::checkAdminUser'
);
