<?php

/**
 * This file contains package_quiqqer_dashboard_ajax_backend_getCards
 */

use QUI\ERP\Order\Handler as OrderHandler;

/**
 * @return array
 */
QUI::$Ajax->registerFunction(
    'package_ecoyn_dashboard_ajax_backend_getSalesComparison',
    function ($time) {
        $PDO = QUI::getDataBase()->getPDO();
        $table = QUI::getDBTableName('orders');
        $time = json_decode($time, true);

        $from = (int)$time['from'];
        $to = (int)$time['to'];
        $interval = $time['interval'];

        $from = date('Y-m-d H:i:s', $from);
        $to = date('Y-m-d H:i:s', $to);

        $query = '
            SELECT `id`, `c_date`
            FROM ' . $table . ' 
            WHERE c_date >= :from AND  c_date <= :to
            ';

        $Statement = $PDO->prepare($query);

        $Statement->bindParam(':from', $from);
        $Statement->bindParam(':to', $to);
        $Statement->execute();

        $data = $Statement->fetchAll(PDO::FETCH_ASSOC);
        $FromDate = date_create($from);
        $ToDate = date_create($to);

        $timeframes = [];

        switch ($interval) {
            case 'days':
                $Interval = new DateInterval('P1D');
                $Period = new DatePeriod($FromDate, $Interval, $ToDate);

                foreach ($Period as $Day) {
                    $firstDay = $Day->format('Y-m-d') . ' 00:00:00';
                    $lastDay = $Day->format('Y-m-d') . ' 23:59:59';

                    $timeframes[] = [
                        'from' => $firstDay,
                        'to' => $lastDay
                    ];
                }
                break;

            case 'months':
                $Interval = new DateInterval('P1M');
                $Period = new DatePeriod($FromDate, $Interval, $ToDate);

                foreach ($Period as $Month) {
                    $firstDay = $Month->format('Y-m') . '-01';
                    $lastDay = $Month->format('Y-m-t');

                    $timeframes[] = [
                        'from' => $firstDay,
                        'to' => $lastDay
                    ];
                }

                break;

            case 'years':
                $Interval = new DateInterval('P1Y');
                $Period = new DatePeriod($FromDate, $Interval, $ToDate);

                foreach ($Period as $Year) {
                    $firstDay = $Year->format('Y') . '-01-01';
                    $lastDay = $Year->format('Y') . '-12-31';

                    $timeframes[] = [
                        'from' => $firstDay,
                        'to' => $lastDay
                    ];
                }
                break;
        }

        // Bestellungen für jede Zeitraum
        $netSumPerTimeframe = [];
        $Orders = OrderHandler::getInstance();
        $Currency = QUI\ERP\Defaults::getCurrency();
        $Locale = QUI::getLocale();

        foreach ($timeframes as $timeframe) {
            $FromTimeframe = date_create($timeframe['from']);
            $ToTimeframe = date_create($timeframe['to']);
            $netSum = 0;

            foreach ($data as $row) {
                $OrderCreateDate = date_create($row['c_date']);

                if ($OrderCreateDate >= $FromTimeframe && $OrderCreateDate <= $ToTimeframe) {
                    $Order = $Orders->get($row['id']);

                    $PriceCalculation = $Order->getPriceCalculation();
                    $netSum += $PriceCalculation->getNettoSum()->get();
                }
            }

            $netSumPerTimeframe[] = [
                'from' => $timeframe['from'],
                'to' => $timeframe['to'],
                'netSum' => $netSum,
                'netSumFormat' => $Currency->format($netSum, $Locale)
            ];
        }

        return [
            'data' => $netSumPerTimeframe,
            'interval' => $interval
        ];
    },
    ['time'],
    'Permission::checkAdminUser'
);
