/**
 * @module package/ecoyn/dashboard/bin/backend/controls/Dashboard
 * @author www.pcsg.de (Henning Leutz)
 */

define('package/ecoyn/dashboard/bin/backend/controls/Dashboard', [

    'qui/QUI',
    'qui/controls/Control',
    'package/quiqqer/erp/bin/backend/controls/elements/TimeFilter',

    'css!package/ecoyn/dashboard/bin/backend/controls/Dashboard.css',
    'Locale'

], function (QUI, QUIControl, TimeFilter) {
    "use strict";

    return new Class({

        Extends: QUIControl,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/Dashboard',

        initialize: function (options) {
            this.parent(options);

            this.$Loader = null;

            this.addEvents({
                onImport: this.$onImport
            });
        },

        $onImport: function () {
            const Col = document.body.getElement('.page-header .col');

            Col.setStyles({
                position: 'relative'
            });

            this.$Loader = new Element('div.loader-container', {
                html  : '<div class="loader"></div>',
                styles: {
                    display : 'none',
                    height  : '100%',
                    left    : 0,
                    position: 'absolute',
                    top     : 0,
                    width   : '100%'
                }
            }).inject(document.body);

            const TimeContainer = new Element('div', {
                'class': 'time-select',
                styles : {
                    position: 'absolute',
                    right   : 0,
                    top     : 0
                }
            }).inject(Col);

            this.$TimeFilter = new TimeFilter({
                name  : 'timeFilter',
                styles: {
                    'float': 'right'
                },
                events: {
                    onChange: () => {
                        let cards = this.getCards();
                        let promises = cards.map((Card) => {
                            return Card.refresh();
                        });

                        this.$Loader.setStyle('display', 'flex');

                        Promise.all(promises).then(() => {
                            this.$Loader.setStyle('display', 'none');
                        }).catch((err) => {
                            console.error(err);
                            this.$Loader.setStyle('display', 'none');
                        });

                    }
                }
            }).inject(TimeContainer);
        },

        /**
         * @return {*}
         */
        getTime: function () {
            return this.$TimeFilter.getValue();
        },

        /**
         * Return all dash board cards
         *
         * @returns {Array}
         */
        getCards: function () {
            return document.body.getElements('.dashboard-card').map((node) => {
                return QUI.Controls.getById(node.get('data-quiid'));
            });
        }
    });
});
