/**
 * @module package/ecoyn/dashboard/bin/backend/controls/cards/Category
 * @author www.pcsg.de (Serpil Ülker)
 */
define('package/ecoyn/dashboard/bin/backend/controls/cards/Category', [

    'package/quiqqer/dashboard/bin/backend/controls/Card',
    'package/ecoyn/dashboard/bin/backend/utils/Utils',
    'Ajax',
    'Locale',
    URL_OPT_DIR + 'bin/quiqqer-asset/chart.js/chart.js/dist/chart.umd.js'

], function (QUICard, Utils, QUIAjax, QUILocale, Chart) {
    "use strict";

    return new Class({

        Extends: QUICard,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/cards/Category',

        Binds: [
            '$onCreate'
        ],

        initialize: function (options) {
            this.parent(options);

            this.setAttribute({
                content : '',
                priority: 85
            });

            this.addEvents({
                onCreate: this.$onCreate
            });
        },

        refresh: function () {
            const self = this;

            if (!Utils.getTime()) {
                return Promise.resolve();
            }

            return new Promise((resolve, reject) => {
                QUIAjax.get('package_ecoyn_dashboard_ajax_backend_getCategory', function (result) {
                    const Elm = self.getElm();
                    const Body = Elm.getElement('.card-body');

                    Body.set('html', '');

                    if (typeOf(result) === 'array' && !result.length) {
                        Body.set('html', QUILocale.get('ecoyn/dashboard', 'no.results'));
                        Body.setStyle('display', null);

                        resolve();
                        return;
                    }

                    const Canvas = new Element('canvas', {
                        'class': "canvas-test",
                        style  : {
                            height: 80
                        }
                    }).inject(Body);

                    Body.setStyle('display', null);

                    let sum = [];
                    let title = [];

                    // sorting
                    Object.entries(result).sort(function (a, b) {
                        a = a[1];
                        b = b[1];

                        return a.sum > b.sum ? -1 : 1;
                    }).forEach(function (entry) {
                        title.push(entry[1].title);
                        sum.push(entry[1].sum);
                    });

                    new Chart(Canvas, {
                        type: 'horizontalBar',
                        data: {
                            labels  : title,
                            datasets: [
                                {
                                    label          : QUILocale.get('ecoyn/dashboard', 'ecoyn.category'),
                                    data           : sum,
                                    borderColor    : '#00e0a2b3',
                                    backgroundColor: '#00e0a2b3'
                                }
                            ]
                        }
                    });

                    resolve();
                }, {
                    'package': 'ecoyn/dashboard',
                    time     : JSON.encode(Utils.getTime()),
                    onError  : reject
                });
            });
        },

        $onCreate: function () {
            const self = this;

            this.getElm().classList.add('col-sg-6');
            this.getElm().classList.add('col-sm-6');

            if (!Utils.getBoard()) {
                return;
            }

            Utils.getBoard().addEvent('onChange', function () {
                return self.refresh();
            });
        }
    });
});
