/**
 * @module package/ecoyn/dashboard/bin/backend/controls/cards/Customer
 * @author www.pcsg.de (Serpil Ülker)
 */
define('package/ecoyn/dashboard/bin/backend/controls/cards/Customer', [
    'package/quiqqer/dashboard/bin/backend/controls/Card',
    'package/ecoyn/dashboard/bin/backend/utils/Utils',
    'Ajax',
    'Locale',
    'Mustache',

    URL_OPT_DIR + 'bin/quiqqer-asset/chart.js/chart.js/dist/chart.umd.js',
    'text!package/ecoyn/dashboard/bin/backend/controls/cards/Customer.html',

], function (QUICard, Utils, QUIAjax, QUILocale, Mustache, Chart, customertemplate) {
    "use strict";

    return new Class({

        Extends: QUICard,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/cards/Customer',

        Binds: [
            '$onCreate'
        ],

        initialize: function (options) {
            this.parent(options);

            this.setAttribute({
                content : '',
                priority: 85
            });

            this.addEvents({
                onCreate: this.$onCreate
            });
        },

        /**
         * refresh the display
         */
        refresh: function () {
            const self = this;

            if (!Utils.getTime()) {
                return Promise.resolve();
            }


            return new Promise((resolve, reject) => {
                QUIAjax.get('package_ecoyn_dashboard_ajax_backend_getCustomer', function (result) {
                    const html = Mustache.render(customertemplate, {
                        totalCustomer: result.total,
                        newCustomer  : result.customer
                    });

                    self.setContent(html);

                    const Elm = self.getElm();
                    const Canvas = Elm.getElement('.canvas-test');

                    new Chart(Canvas, {
                        type: 'horizontalBar',
                        data: {
                            labels  :
                                [
                                    QUILocale.get("ecoyn/dashboard", "ecoyn.top.customer.total"),
                                    QUILocale.get("ecoyn/dashboard", "dashboard.stats.new.customer")
                                ],
                            datasets: [
                                {
                                    label          : [QUILocale.get("ecoyn/dashboard", "ecoyn.customer.all")],
                                    data           : [
                                        Elm.getElement('[name="total-customer"]').getAttribute('data-qui-total'),
                                        Elm.getElement('[name="new-customer"]').getAttribute('data-qui-new')
                                    ],
                                    fill           : false,
                                    backgroundColor: [
                                        "#79a6dc",
                                        "#206bc4"
                                    ],
                                    borderColor    : [
                                        "#79a6dc",
                                        "#206bc4"
                                    ],
                                    borderWidth    : 1
                                }
                            ]
                        },
                    });

                    resolve();
                }, {
                    'package': 'ecoyn/dashboard',
                    time     : JSON.encode(Utils.getTime()),
                    onError  : reject
                });
            });
        },

        $onCreate: function () {
            const self = this;

            this.getElm().classList.add('col-sg-6');
            this.getElm().classList.add('col-sm-6');

            if (!Utils.getBoard()) {
                return;
            }

            Utils.getBoard().addEvent('onChange', function () {
                self.refresh();
            });
        }
    });
});
