/**
 * @module package/ecoyn/dashboard/bin/backend/controls/cards/LastOrders
 * @author www.pcsg.de (Serpil Ülker)
 */
define('package/ecoyn/dashboard/bin/backend/controls/cards/LastOrders', [

    'package/quiqqer/dashboard/bin/backend/controls/Card',
    'package/ecoyn/dashboard/bin/backend/utils/Utils',
    'Ajax',
    'Locale',
    'Mustache',

    'text!package/ecoyn/dashboard/bin/backend/controls/cards/LastOrders.html',
    'css!package/ecoyn/dashboard/bin/backend/controls/cards/LastOrders.css'

], function (QUICard, Utils, QUIAjax, QUILocale, Mustache, contentTemplate) {
    "use strict";

    const lg = 'ecoyn/dashboard';

    return new Class({

        Extends: QUICard,
        Type   : 'package/ecoyn/dashboard/bin/backend/controls/cards/LastOrders',

        Binds: [
            '$onCreate'
        ],

        initialize: function (options) {
            this.parent(options);

            this.setAttributes({
                content : '',
                priority: 85
            });

            this.addEvents({
                onCreate: this.$onCreate
            });
        },

        refresh: function () {
            const self = this;

            if (!Utils.getTime()) {
                return Promise.resolve();
            }


            return new Promise((resolve, reject) => {
                QUIAjax.get('package_ecoyn_dashboard_ajax_backend_getLastOrders', function (result) {
                    let rows = "";

                    const data = result;
                    const Tbody = self.getElm().getElement('tbody');
                    Tbody.set('html', '');

                    const orderClick = function (event) {
                        let Target = event.target;

                        if (Target.nodeName !== 'TD') {
                            Target = Target.getParent('td');
                        }

                        window.parent.require([
                            'utils/Panels',
                            'package/quiqqer/order/bin/backend/controls/panels/Order'
                        ], function (PanelUtils, OrdersPanel) {
                            PanelUtils.openPanelInTasks(
                                new OrdersPanel({
                                    orderId: Target.get('data-orderid')
                                })
                            );
                        });
                    };

                    const userClick = function (event) {
                        let Target = event.target;

                        if (Target.nodeName !== 'TD') {
                            Target = Target.getParent('td');
                        }

                        window.parent.require([
                            'utils/Panels',
                            'controls/users/User'
                        ], function (PanelUtils, UsersPanel) {
                            PanelUtils.openPanelInTasks(
                                new UsersPanel(Target.get('data-user'))
                            );
                        });
                    };

                    if (!data.length) {
                        rows += "<tr>" +
                                "    <td colspan='5'>" + QUILocale.get(lg, 'no.results') + "</td>" +
                                "</tr>";
                    } else {
                        data.forEach(function (DataSet) {
                            rows += '<tr>' +
                                    '    <td class="ecoyn-dashboard-last-order-orderId" data-orderid="' + DataSet.id +
                                    '">' + DataSet.id + '</td>' +
                                    '    <td>' + DataSet.c_date + '</td>' +
                                    '    <td data-user="' + DataSet.userId +
                                    '" class="ecoyn-dashboard-last-order-user">' +
                                    DataSet.firstname + ' ' + DataSet.lastname +
                                    '</td>' +
                                    '    <td>' +
                                    DataSet.articles.map(
                                        articles => articles.title + '; ' + ' ' + articles.display_unitPrice
                                    ).join(', ') +
                                    '</td>' +
                                    '<td>' + DataSet.display_sum + '</td>' +
                                    '</tr>';
                        });
                    }

                    self.getElm().getElement('tbody').set('html', rows);
                    self.getElm().getElements('[data-orderid]').addEvent('click', orderClick);
                    self.getElm().getElements('[data-user]').addEvent('click', userClick);

                    resolve();
                }, {
                    'package': 'ecoyn/dashboard',
                    time     : JSON.encode(Utils.getTime()),
                    onError  : reject
                });
            });
        },

        $onCreate: function () {
            if (!Utils.getBoard()) {
                return;
            }

            this.$Content.addClass('card-table');
            this.$Content.removeClass('card-body');

            this.getElm().classList.add('col-sg-12');
            this.getElm().classList.add('col-sm-12');

            this.setAttribute({
                head_title: QUILocale.get(lg, 'ecoyn.last.orders')
            });

            this.setContent(Mustache.render(contentTemplate, {
                orderNo : QUILocale.get(lg, 'ecoyn.top.product.orderNo'),
                title   : QUILocale.get(lg, 'ecoyn.last.orders'),
                datum   : QUILocale.get(lg, 'ecoyn.top.product.date'),
                name    : QUILocale.get(lg, 'ecoyn.customer.name'),
                articles: QUILocale.get(lg, 'ecoyn.customer.article'),
                price   : QUILocale.get(lg, 'ecoyn.customer.price')
            }));

            Utils.getBoard().addEvent('onChange', () => {
                this.refresh();
            });
        }
    });
});
